@@ -17,17 +17,14 @@
  *  You can contact the author at: mark _dot_ vanderloo _at_ gmail _dot_ com
  */
 
-#define USE_RINTERNALS
 #include <stdlib.h>
 #include <stdint.h>
-#include <R.h>
-#include <Rdefines.h>
 #include <math.h>
-#include "utils.h"
-#include "stringdist.h"
 #ifdef _OPENMP
 #include <omp.h>
 #endif
+#include "utils.h"
+#include "stringdist.h"
 
 #define MIN(X,Y) ((X) < (Y) ? (X) : (Y))
 #define MAX(X,Y) ((X) > (Y) ? (X) : (Y))
@@ -67,7 +64,7 @@ SEXP R_stringdist(SEXP a, SEXP b, SEXP method
  
   // output vector
   SEXP yy;
-  PROTECT(yy = allocVector(REALSXP, nt));
+  yy = PROTECT(allocVector(REALSXP, nt));
   double *y = REAL(yy);
 
   #ifdef _OPENMP 
@@ -152,7 +149,7 @@ SEXP R_amatch(SEXP x, SEXP table, SEXP method
 
   // output vector
   SEXP yy;
-  PROTECT(yy = allocVector(INTSXP, nx));
+  yy = PROTECT(allocVector(INTSXP, nx));
   int *y = INTEGER(yy);
   
   #ifdef _OPENMP
@@ -217,7 +214,7 @@ SEXP R_amatch(SEXP x, SEXP table, SEXP method
 
 // Lower tridiagonal distance matrix for a single vector argument.
 
-static int get_j(R_xlen_t k, int n){
+static int get_j(R_xlen_t k, R_xlen_t n){
   double nd = (double) n;
   double kd = (double) k;
   double u = ceil( (2.*nd - 3.)/2. - sqrt(pow(nd-.5,2.) - 2.*(kd + 1.)) );
@@ -247,13 +244,13 @@ SEXP R_lower_tri(SEXP a, SEXP method
     , N = n*(n-1)/2;
 
   if ( n > MAXN ){
-    error("Length of input vector (%d) exceeds maximum allowed for this platform (%d)",n,MAXN);
+    error("Length of input vector (%1.0f) exceeds maximum allowed for this platform (%1.0f)",(double) n,(double) MAXN);
   }  
  
  
   // output vector
   SEXP yy;
-  PROTECT(yy = allocVector(REALSXP, N));
+  yy = PROTECT(allocVector(REALSXP, N));
   // nothing to do if n=1 
   if (n == 1L) goto end ;
   double *y = REAL(yy);
@@ -282,13 +279,14 @@ SEXP R_lower_tri(SEXP a, SEXP method
     t = s + ml + 1L;
       
     int len_s, len_t, isna_s, isna_t
-      , i = 0, j = 0
+      , j = 0
       , thread_id = 0
-      , n_threads = 1
-      , col_max = n-1;
+      , n_threads = 1;
 
     R_xlen_t pp = 0
       , k_start = 0
+      , i = 0
+      , col_max = n-1
       , k_end = N;
 
     #ifdef _OPENMP
@@ -299,7 +297,7 @@ SEXP R_lower_tri(SEXP a, SEXP method
       pp = N / n_threads;
       k_start = thread_id * pp;
       k_end   = (thread_id < n_threads - 1 ) ? k_start + pp : N;
-      j = get_j(k_start,n);
+      j = get_j(k_start, n);
       i = k_start + j * (j - 2*n + 3)/2;
     for ( R_xlen_t k=k_start; k < k_end; k++ ){
       i++;
@@ -348,7 +346,7 @@ SEXP R_afind(SEXP a, SEXP pattern, SEXP width
 
   // output list
   SEXP out_list;
-  PROTECT(out_list = allocVector(VECSXP, 2));
+  out_list = PROTECT(allocVector(VECSXP, 2));
 
   // output location
   SEXP out_loc = PROTECT(allocMatrix(INTSXP, na, npat));
@@ -443,7 +441,7 @@ SEXP R_afind(SEXP a, SEXP pattern, SEXP width
 // helper function to determine  whether all is INTSXP
 
 SEXP R_all_int(SEXP X){
-  PROTECT(X);
+  
   SEXP all_int;
   all_int = PROTECT(allocVector(LGLSXP,1L));
 
@@ -456,7 +454,7 @@ SEXP R_all_int(SEXP X){
     }
   }
 
-  UNPROTECT(2);
+  UNPROTECT(1);
   return all_int;
 
 }
