@@ -18,9 +18,6 @@
  */
 
 #include "utils.h"
-#ifdef _OPENMP
-#include <omp.h>
-#endif
 
 
 /* Levenshtein distance
